==> hboard-1.0-rc1.tar.gz: hboard/modify.php <==
<?php

/* EtchiBoard Version 1.0
     modify.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  /ϴܺ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader();

if(!$article_no) {
 PrintMessage("<b>Խù  ϴ.</b><br>modify.php?article_no=[ȣ]  Էϼ.", "error");
}

else {

/* Խù  о (...ִ ɵ  ְ ؼ -_-a) */
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_query("select * from hboard_db_article where idx='${article_no}'", $dbconnect);

$article[writer] = mysql_result($result, 0, "name"); // ̸
$article[cfile] = mysql_result($result, 0, "cfile"); // ÷
$article[mailz] = mysql_result($result, 0, "email"); // ̸
$article[homepy] = mysql_result($result, 0, "home"); // Ȩ
$article[title] = mysql_result($result, 0, "subject"); // 
$article[ment] = mysql_result($result, 0, "ment"); //  
$article[deleted] = mysql_result($result, 0, "deleted"); //  
mysql_close($dbconnect);

/* Խù  üũ, ̻  ̱ */
if($article[deleted] == "t") {
 PrintMessage("Խù ̹  Դϴ.", "error");
}

else {
?>
<script language="JavaScript" type="">

function Preview(Change_form,i){
        var strPath;
        d_pic = "db/img/<?=$article[cfile]?>";
        document.all(d_pic).innerHTML="<IMG alt='Preview' border=0 name=pic1 src='" + eval("Change_form.picture.value") + "' style='visibility:hidden'>";
        stretch_i="stretchimage('320','240','1')";
        window.setTimeout(stretch_i,1000);
}

function stretchimage(iw,ih,j){
	iWidth=parseInt(eval("document.pic"+j+".width"));
	iHeight=parseInt(eval("document.pic"+j+".height"));
	if(iWidth>parseInt(iw) && iWidth>=iHeight){
		eval('document.pic'+j+'.height=parseInt(iw)/iWidth*iHeight;');
		eval('document.pic'+j+'.width=parseInt(iw);');
	}
	else if(iHeight>parseInt(ih) && iHeight>iWidth){
		eval('document.pic'+j+'.width=parseInt(ih)/iHeight*iWidth;');
		eval('document.pic'+j+'.height=parseInt(ih);');
	}

	eval('document.pic'+j+'.style.visibility="visible";');
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}

<?php
if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  α ° ƴϸ, йȣ ԷȮ ũƮ Ȱ (_)
?>
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
<?php
}
?>
		else if(document.inputform.title.value == ""){
			alert("  Է ּ.");
			document.inputform.title.focus();
			return true;
		}
		else if(document.inputform.ne.value == ""){
			alert("Խù ̳   Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}

</script>

<!--   κ  -->

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="974" height="20">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="20" background="skin/<?=$admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?=$admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="25" background="skin/<?=$admin_data[skin]?>/title_bg.gif">
<p><font color="<?=$skin[sfont2_color]?>">&nbsp;<b><?=$article_no?> Խù ϱ..</b></font></p>
</td></tr>
</table>
</td></tr>

<tr><td>
<form name="inputform" method="post" action="post_modify.php" onsubmit="this.submit_btn.disabled=true">

<input type=hidden name=article_no value="<?=$article_no?>">
<input type=hidden name=page value="<?=$page?>">

<TABLE border=1 width=640 cellspacing=0 cellpadding=7 bgcolor="<?=$skin[image_table_bgcolor]?>"><TR ALIGN=CENTER><TD>
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD WIDTH=50>Name</TD>
<TD><INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=50 VALUE="<?=$article[writer]?>"></TD></TR>

<TR><TD>Mail</TD><TD>
<INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=255 VALUE="<?=$article[mailz]?>"></TD></TR>

<TR><TD>URL(*)</TD><TD>
<INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($article[homepy] == "") {
	echo "http://"; }
else {
	echo $article[homepy]; }
?>"></TD></TR>

<?php
if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  α ° ƴϸ, йȣ Էâ 
?>
<TR><TD>Password</TD><TD>
 <INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=16>
<span style="font-size:8pt;">
( ۼ ԷϿ йȣ)</span></TD></TR>
<?php
}
?>

<TR><TD WIDTH=50>Title</TD><TD>
 <input type=text name="title" size=32 maxlength=255 value="<?=$article[title]?>"></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD><TEXTAREA NAME="ne" ROWS=7 COLS=45>
<?=$article[ment]?>
</TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<br>
<INPUT name="submit_btn" type=button value="Submit" onclick="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" type=reset value="Reset">
<a href="list.php?page=<?=$page ."#" .$article_no?>">[ǵư]</a>
</TD></TR>
</TABLE>
</td></tr></table>
</td>

<TD WIDTH=320 HEIGHT=240>
<DIV id='d_pic1' style='width:320px;height:240px;overflow:hidden;' align='center'>
<IMG border='0' name='pic1' SRC='skin/<?=$admin_data[skin]?>/preview.jpg' WIDTH='320' HEIGHT='240' alt='Preview'>
</DIV>
</TD></tr>
</table>
</form>
</td></tr>
</table>
<!--   κ  -->
<?php
 echo "<center>\n";
  PrintArticle($article_no, $article_no, false);
 echo "\n</center>\n";
 }
}
PrintFooter();
?>

==> hboard-1.0.1.tar.gz: hboard/modify.php <==
<?php

/* EtchiBoard Version 1.0
     modify.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  /ϴܺ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader();

if(!$article_no) {
 PrintMessage("<b>Խù  ϴ.</b><br>modify.php?article_no=[ȣ]  Էϼ.", "error");
}

else {

/* Խù  о (...ִ ɵ  ְ ؼ -_-a) */
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_query("select * from hboard_db_article where idx='${article_no}'", $dbconnect);

$article[writer] = mysql_result($result, 0, "name"); // ̸
$article[cfile] = mysql_result($result, 0, "cfile"); // ÷
$article[mailz] = mysql_result($result, 0, "email"); // ̸
$article[homepy] = mysql_result($result, 0, "home"); // Ȩ
$article[title] = mysql_result($result, 0, "subject"); // 
$article[ment] = mysql_result($result, 0, "ment"); //  
$article[deleted] = mysql_result($result, 0, "deleted"); //  
mysql_close($dbconnect);

/* Խù  üũ, ̻  ̱ */
if($article[deleted] == "t") {
 PrintMessage("Խù ̹  Դϴ.", "error");
}

else {
?>
<script language="JavaScript" type="">

function Preview(Change_form,i){
        var strPath;
        d_pic = "db/img/<?php echo $article[cfile]?>";
        document.all(d_pic).innerHTML="<IMG alt='Preview' border=0 name=pic1 src='" + eval("Change_form.picture.value") + "' style='visibility:hidden'>";
        stretch_i="stretchimage('320','240','1')";
        window.setTimeout(stretch_i,1000);
}

function stretchimage(iw,ih,j){
	iWidth=parseInt(eval("document.pic"+j+".width"));
	iHeight=parseInt(eval("document.pic"+j+".height"));
	if(iWidth>parseInt(iw) && iWidth>=iHeight){
		eval('document.pic'+j+'.height=parseInt(iw)/iWidth*iHeight;');
		eval('document.pic'+j+'.width=parseInt(iw);');
	}
	else if(iHeight>parseInt(ih) && iHeight>iWidth){
		eval('document.pic'+j+'.width=parseInt(ih)/iHeight*iWidth;');
		eval('document.pic'+j+'.height=parseInt(ih);');
	}

	eval('document.pic'+j+'.style.visibility="visible";');
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}

<?php
if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  α ° ƴϸ, йȣ ԷȮ ũƮ Ȱ (_)
?>
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
<?php
}
?>
		else if(document.inputform.ne.value == ""){
			alert("Խù ̳   Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}

</script>

<!--   κ  -->

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="974" height="20">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?php echo $admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="25" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p><font color="<?php echo $skin[sfont2_color]?>">&nbsp;<b><?php echo $article_no?> Խù ϱ..</b></font></p>
</td></tr>
</table>
</td></tr>

<tr><td>
<form name="inputform" method="post" action="post_modify.php" onsubmit="this.submit_btn.disabled=true">

<input type=hidden name=article_no value="<?php echo $article_no?>">
<input type=hidden name=page value="<?php echo $page?>">

<TABLE border=1 width=640 cellspacing=0 cellpadding=7 bgcolor="<?php echo $skin[image_table_bgcolor]?>"><TR ALIGN=CENTER><TD>
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD WIDTH=50>Name</TD>
<TD><INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=30 VALUE="<?php echo $article[writer]?>"></TD></TR>

<TR><TD>Mail</TD><TD>
<INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=100 VALUE="<?php echo $article[mailz]?>"></TD></TR>

<TR><TD>URL(*)</TD><TD>
<INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($article[homepy] == "") {
	echo "http://"; }
else {
	echo $article[homepy]; }
?>"></TD></TR>

<?php
if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  α ° ƴϸ, йȣ Էâ 
?>
<TR><TD>Password</TD><TD>
 <INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=30>
<span style="font-size:8pt;">
( ۼ ԷϿ йȣ)</span></TD></TR>
<?php
}
?>

<TR><TD WIDTH=50>Title</TD><TD>
 <input type=text name="title" size=32 maxlength=255 value="<?php echo $article[title]?>"></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD><TEXTAREA NAME="ne" ROWS=7 COLS=45>
<?php echo $article[ment]?>
</TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<br>
<INPUT name="submit_btn" type=button value="Submit" onclick="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" type=reset value="Reset">
<a href="list.php?page=<?php echo $page ."#" .$article_no?>">[ǵư]</a>
</TD></TR>
</TABLE>
</td></tr></table>
</td>

<TD WIDTH=320 HEIGHT=240>
<DIV id='d_pic1' style='width:320px;height:240px;overflow:hidden;' align='center'>
<IMG border='0' name='pic1' SRC='skin/<?php echo $admin_data[skin]?>/preview.jpg' WIDTH='320' HEIGHT='240' alt='Preview'>
</DIV>
</TD></tr>
</table>
</form>
</td></tr>
</table>
<!--   κ  -->
<?php
 echo "<center>\n";
  PrintArticle($article_no, $article_no, false);
 echo "\n</center>\n";
 }
}
PrintFooter();
?>
